"use client"
import { useRouter } from 'next/navigation'
import LoginModal from '../../components/header/LoginModal'
import React, { useState, useEffect } from 'react'
import axios from '@/services/APIservices'

const Form = () => {
    const router = useRouter()
    const [role, setRole] = useState("Agent")
    const [isLoginModalOpen, setIsLoginModalOpen] = useState(false)
    const [isLogin, setIsLogin] = useState(true)
    const [formData, setFormData] = useState({
        name: '',
        phoneNumber: ''
    })
    const [userId, setUserId] = useState("")
    const [loginMessage, setLoginMessage] = useState("")
    const [showMessage, setShowMessage] = useState(false)
    const [isLoggedIn, setIsLoggedIn] = useState(false)
    const [isSubmitting, setIsSubmitting] = useState(false)
    const [submitStatus, setSubmitStatus] = useState({ type: '', message: '' })

    const fetchUserData = () => {
        const storedUserData = localStorage.getItem("userData")
        if (storedUserData) {
            const parsedUserData = JSON.parse(storedUserData)
            const id = parsedUserData.user_id || ""
            setUserId(id)
            setIsLoggedIn(!!id)
        } else {
            setUserId("")
            setIsLoggedIn(false)
        }
    }

    useEffect(() => {
        fetchUserData()
    }, [])

    useEffect(() => {
        if (!isLoginModalOpen) {
            fetchUserData()
        }
    }, [isLoginModalOpen])

    const handleInputChange = (field, value) => {
        setFormData(prev => ({
            ...prev,
            [field]: value
        }))
        setSubmitStatus({ type: '', message: '' })
    }

    const validateForm = () => {
        if (!formData.name.trim()) {
            setSubmitStatus({
                type: 'error',
                message: 'Name is required'
            })
            return false
        }
        if (!formData.phoneNumber.trim()) {
            setSubmitStatus({
                type: 'error',
                message: 'Phone number is required'
            })
            return false
        }
        const phoneRegex = /^[0-9]{10}$/
        if (!phoneRegex.test(formData.phoneNumber)) {
            setSubmitStatus({
                type: 'error',
                message: 'Please enter a valid 10-digit phone number'
            })
            return false
        }
        return true
    }

    const handleSubmit = async () => {
        if (!userId) {
            setLoginMessage("Please login or register first to post your property")
            setShowMessage(true)
            setIsLoginModalOpen(true)
            return
        }

        if (!validateForm()) return

        setIsSubmitting(true)
        setSubmitStatus({ type: '', message: '' })






        try {
            const response = await axios.post(`api/SubUser-register/${userId}`, {
                role: role,
                name: formData.name,
                phone_number: formData.phoneNumber
            });
        
            // Handle the case where user data already exists
            if (response.data.status === 'existing_user') {
                setSubmitStatus({
                    type: 'success',
                    message: 'Welcome, you are the main user!'
                });
        
                setTimeout(() => {
                    if (response.data.role === "Developer") {
                        router.push(`/developerForm/${response.data.userId}?postID=${response.data.postID}`);
                    } else {
                        // Updated line to include postID in the URL
                        router.push(`/agentLandowner_form/${response.data.userId}?postID=${response.data.postID}`);
                    }
                }, 1000);
                return;
            }
        
            setSubmitStatus({
                type: 'success',
                message: 'Registration successful!'
            });
        
            const subUserId = response.data.subUserId;
        
            setTimeout(() => {
                if (role === "Developer") {
                    router.push(`/developerForm/${userId}?subuser=${subUserId}`);
                } else {
                    router.push(`/agentLandowner_form/${userId}?subuser=${subUserId}`);
                }
            }, 1000);
        
        } catch (error) {
            setSubmitStatus({
                type: 'error',
                message: error.response?.data?.message || 'An error occurred. Please try again.'
            });
        } finally {
            setIsSubmitting(false);
        }
        





    }

    const handleLoginClick = () => {
        setLoginMessage("Please login or register to continue")
        setShowMessage(true)
        setIsLoginModalOpen(true)
    }

    const handleModalClose = () => {
        setIsLoginModalOpen(false)
        setShowMessage(false)
    }

    return (
        <div className='min-h-screen bg-gray-50 flex items-center justify-center p-4 sm:p-6 lg:p-8'>
            <div className='bg-white py-8 px-6 rounded-xl shadow-lg max-w-2xl w-full'>
                <div className='space-y-6'>
                    {/* Header Section */}
                    <div className='space-y-4'>
                        <h2 className='text-2xl font-bold text-gray-900 sm:text-3xl text-center'>
                            Start posting your property for free
                        </h2>
                        <div className="flex items-center justify-center gap-2 flex-wrap">
                            <p className='font-semibold text-gray-700'>Are you?</p>
                            {isLoggedIn && (
                                <span className="text-green-600 text-sm font-medium bg-green-50 px-4 py-1.5 rounded-full">
                                    Ready to proceed
                                </span>
                            )}
                        </div>
                    </div>

                    {/* Role Selection */}
                    <div className="flex flex-wrap justify-center gap-3">
                        {["Landowner", "Agent", "Developer"].map(item => (
                            <button
                                onClick={() => setRole(item)}
                                className={`${
                                    item === role 
                                        ? "bg-brand text-white shadow-md" 
                                        : "border-2 border-gray-200 text-gray-700 hover:border-brand"
                                } rounded-lg py-2 px-6 text-base font-medium transition-all duration-200`}
                                key={item}
                            >
                                {item}
                            </button>
                        ))}
                    </div>

                    {/* Contact Details Section */}
                    <div className="space-y-4">
                        <p className='font-semibold text-gray-700 text-center'>
                            Contact details for buyer communication
                        </p>
                        <div className="space-y-4">
                            <div className="relative">
                                <input
                                    placeholder="Full Name"
                                    value={formData.name}
                                    onChange={(e) => handleInputChange('name', e.target.value)}
                                    className="w-full px-4 py-3 rounded-lg border-2 border-gray-200 focus:border-brand focus:ring-2 focus:ring-brand focus:ring-opacity-20 outline-none transition-all duration-200 text-gray-900 placeholder-gray-500 bg-white text-base"
                                />
                                <div className="absolute inset-y-0 right-0 flex items-center pr-3 pointer-events-none">
                                    <svg className="w-5 h-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M16 7a4 4 0 11-8 0 4 4 0 018 0zM12 14a7 7 0 00-7 7h14a7 7 0 00-7-7z" />
                                    </svg>
                                </div>
                            </div>
                            <div className="relative">
                                <input
                                    placeholder="Phone Number"
                                    value={formData.phoneNumber}
                                    onChange={(e) => handleInputChange('phoneNumber', e.target.value)}
                                    className="w-full px-4 py-3 rounded-lg border-2 border-gray-200 focus:border-brand focus:ring-2 focus:ring-brand focus:ring-opacity-20 outline-none transition-all duration-200 text-gray-900 placeholder-gray-500 bg-white text-base"
                                    type="tel"
                                    pattern="[0-9]{10}"
                                    maxLength="10"
                                />
                                <div className="absolute inset-y-0 right-0 flex items-center pr-3 pointer-events-none">
                                    <svg className="w-5 h-5 text-gray-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                                        <path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M3 5a2 2 0 012-2h3.28a1 1 0 01.948.684l1.498 4.493a1 1 0 01-.502 1.21l-2.257 1.13a11.042 11.042 0 005.516 5.516l1.13-2.257a1 1 0 011.21-.502l4.493 1.498a1 1 0 01.684.949V19a2 2 0 01-2 2h-1C9.716 21 3 14.284 3 6V5z" />
                                    </svg>
                                </div>
                            </div>
                        </div>
                    </div>

                    {/* Status Messages */}
                    {submitStatus.message && (
                        <div className={`text-sm ${
                            submitStatus.type === 'success' ? 'text-green-600 bg-green-50' : 'text-red-600 bg-red-50'
                        } text-center p-3 rounded-lg font-medium`}>
                            {submitStatus.message}
                        </div>
                    )}

                    {/* Login/Register Section */}
                    <div
                        className="flex items-center justify-center cursor-pointer hover:opacity-80 transition-opacity"
                        onClick={handleLoginClick}
                    >
                        <p className='font-medium text-brand hover:underline'>
                            Login/Register to continue posting property
                        </p>
                    </div>

                    {/* Submit Button */}
                    <div className="flex justify-center pt-4">
                        <button
                            onClick={handleSubmit}
                            disabled={isSubmitting}
                            className={`
                                w-full sm:w-auto
                                bg-brand text-white font-semibold
                                py-3 px-8 rounded-lg
                                transition-all duration-200
                                ${isSubmitting ? 'opacity-70 cursor-not-allowed' : 'hover:opacity-90 hover:shadow-lg'}
                                shadow-md
                            `}
                        >
                            {isSubmitting ? 'Processing...' : 'Get Started'}
                        </button>
                    </div>
                </div>
            </div>

            {/* Login Modal */}
            {isLoginModalOpen && (
                <div className="fixed inset-0 z-50">
                    <LoginModal
                        onClose={handleModalClose}
                        initialView={isLogin ? 'login' : 'register'}
                        message={showMessage ? loginMessage : ""}
                    />
                    {showMessage && (
                        <div className="absolute top-4 left-0 right-0 text-center">
                            <p className="text-sm bg-red-50 text-red-600 py-2 px-4 rounded-lg inline-block">
                                {loginMessage}
                            </p>
                        </div>
                    )}
                </div>
            )}
        </div>
    )
}

export default Form